@@ -13,12 +13,14 @@
 --------------------------------------------------------------------------------
 
 module Graphics.GL.INTEL (
+  module Graphics.GL.INTEL.ConservativeRasterization,
   module Graphics.GL.INTEL.FramebufferCmaa,
   module Graphics.GL.INTEL.MapTexture,
   module Graphics.GL.INTEL.ParallelArrays,
   module Graphics.GL.INTEL.PerformanceQuery
 ) where
 
+import Graphics.GL.INTEL.ConservativeRasterization
 import Graphics.GL.INTEL.FramebufferCmaa
 import Graphics.GL.INTEL.MapTexture
 import Graphics.GL.INTEL.ParallelArrays
